==> segatex-8.500.tar.gz: segatex-8.500/src/seinfo.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEINFO_H
#define SEINFO_H

#include <qdialog.h>
#include <qlayout.h>
#include <qcheckbox.h>
#include <qlabel.h> 
//added by intrajp
#include <QButtonGroup>
#include <QPushButton>
#include <QGroupBox>
#include <qradiobutton.h>
#include <QHBoxLayout>
#include <QVBoxLayout>


class QLayout;
class Q3TextEdit;
class QLineEdit;
class QPushButton;
class SeinfoProcess;

class Seinfo: public QDialog 
{
	Q_OBJECT
public:
	Seinfo(QWidget *parent = 0, const char *name = 0);
	SeinfoProcess *seinfo_process;
public slots:
signals:
protected:
private slots:
	void seinfo_button_clicked();
public:
private:
	QLabel *seinfoLabel;
	QLabel *expressionLabel;
	QPushButton *seinfoButton;
	QPushButton *closeButton;
	QGroupBox *optionButtonGroupBox;
	QGroupBox *optionButtonGroupBox2;
	QGroupBox *createFirstExclusiveGroup();
	QGroupBox *createFirstExclusiveGroup2();
	Q3TextEdit *textEdit1;
	QRadioButton *allRadioButton;
	QRadioButton *classRadioButton;
	QRadioButton *sensitivityRadioButton;
	QRadioButton *categoryRadioButton;
	QRadioButton *typeRadioButton;
	QRadioButton *attributeRadioButton;
	QRadioButton *roleRadioButton;
	QRadioButton *userRadioButton;
	QRadioButton *boolRadioButton;
	QRadioButton *initialsidRadioButton;
	QRadioButton *fs_useRadioButton;
	QRadioButton *genfsconRadioButton;
	QRadioButton *netifconRadioButton;
	QRadioButton *nodeconRadioButton;
	QRadioButton *portconRadioButton;


	QCheckBox *expandCheckBox;
	QCheckBox *statsCheckBox;
	QCheckBox *helpCheckBox;
	QCheckBox *versionCheckBox;
        QLineEdit *seinfoEditLineEdit;
        QLineEdit *expressionEditLineEdit;

	QHBoxLayout *mainLayout;
	QVBoxLayout *leftLayout;
	QVBoxLayout *vbox;
	QVBoxLayout *vbox2;
	QVBoxLayout *rightLayout;

        QString seinfo_str_pp;
        QString seinfo_str_pp_str;
        QString expressionEditLineEdit_str;

};

#endif

==> segatex-8.600.tar.gz: segatex-8.600/src/seinfo.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEINFO_H
#define SEINFO_H

#include <QDialog>
#include <QLayout>
#include <QCheckBox>
#include <QLabel> 
#include <QButtonGroup>
#include <QPushButton>
#include <QGroupBox>
#include <QRadioButton>
#include <QHBoxLayout>
#include <QVBoxLayout>


class QLayout;
class QTextEdit;
class QLineEdit;
class QPushButton;
class SeinfoProcess;

class Seinfo: public QDialog 
{
	Q_OBJECT
public:
	Seinfo(QWidget *parent = 0, const char *name = 0);
	SeinfoProcess *seinfo_process;
public slots:
signals:
protected:
private slots:
	void seinfo_button_clicked();
public:
private:
	QLabel *seinfoLabel;
	QLabel *expressionLabel;
	QPushButton *seinfoButton;
	QPushButton *closeButton;
	QGroupBox *optionButtonGroupBox;
	QGroupBox *optionButtonGroupBox2;
	QGroupBox *createFirstExclusiveGroup();
	QGroupBox *createFirstExclusiveGroup2();
	QTextEdit *textEdit1;
	QRadioButton *allRadioButton;
	QRadioButton *classRadioButton;
	QRadioButton *sensitivityRadioButton;
	QRadioButton *categoryRadioButton;
	QRadioButton *typeRadioButton;
	QRadioButton *attributeRadioButton;
	QRadioButton *roleRadioButton;
	QRadioButton *userRadioButton;
	QRadioButton *boolRadioButton;
	QRadioButton *initialsidRadioButton;
	QRadioButton *fs_useRadioButton;
	QRadioButton *genfsconRadioButton;
	QRadioButton *netifconRadioButton;
	QRadioButton *nodeconRadioButton;
	QRadioButton *portconRadioButton;


	QCheckBox *expandCheckBox;
	QCheckBox *statsCheckBox;
	QCheckBox *helpCheckBox;
	QCheckBox *versionCheckBox;
        QLineEdit *seinfoEditLineEdit;
        QLineEdit *expressionEditLineEdit;

	QHBoxLayout *mainLayout;
	QVBoxLayout *leftLayout;
	QVBoxLayout *vbox;
	QVBoxLayout *vbox2;
	QVBoxLayout *rightLayout;

        QString seinfo_str_pp;
        QString seinfo_str_pp_str;
        QString expressionEditLineEdit_str;

};

#endif
